@@ -34,6 +34,11 @@
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
 #define HAVE_FPU_CONTROL_H 1
+#define HAVE_GETMNTENT 1
+/* #undef HAVE_GETMNTENT_IN_SYS_MNTAB */
+/* #undef HAVE_GETMNTINFO */
+/* #undef HAVE_GETMNTINFO64 */
+/* #undef HAVE_GETMNTINFO_TAKES_statvfs */
 #define HAVE_GRP_H 1
 /* #undef HAVE_IA64INTRIN_H */
 /* #undef HAVE_IEEEFP_H */
@@ -103,6 +108,7 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 #define HAVE_SYSTEMD 1
+#define HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES 1
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -162,14 +168,13 @@
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
-#define HAVE_MEMALIGN 1
 /* #define HAVE_MLOCK 1 see Bug#54662 */
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
 #define HAVE_DECL_MADVISE 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
 #define HAVE_MALLINFO 1
-/* #undef HAVE_MALLINFO2 */
+#define HAVE_MALLINFO2 1
 /* #undef HAVE_MALLOC_ZONE */
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -178,6 +183,7 @@
 #define HAVE_MLOCKALL 1
 #define HAVE_MMAP 1
 #define HAVE_MMAP64 1
+#define HAVE_MPROTECT 1
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
@@ -208,6 +214,7 @@
 #define HAVE_SELECT 1
 #define HAVE_SETENV 1
 #define HAVE_SETLOCALE 1
+#define HAVE_SETMNTENT 1
 #define HAVE_SETUPTERM 1
 #define HAVE_SIGSET 1
 #define HAVE_SIGACTION 1
@@ -428,7 +435,7 @@
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
 /* We don't want the min/max macros */
-#ifdef __WIN__
+#ifdef _WIN32
 #define NOMINMAX 1
 #endif
 
@@ -527,17 +534,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 10
+#define MYSQL_VERSION_MINOR 9
+#define MYSQL_VERSION_PATCH 3
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.10"
+#define PACKAGE_STRING "MySQL Server 10.9.3"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.10"
-#define VERSION "10.5.10"
+#define PACKAGE_VERSION "10.9.3"
+#define VERSION "10.9.3"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
@@ -559,3 +566,5 @@
 #endif  // !defined(__STDC_FORMAT_MACROS)
 
 #endif
+
+#define HAVE_VFORK 1
